.. SKPAR documentation master file, created by
   sphinx-quickstart on Tue Dec 27 01:30:55 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to SKPAR's documentation!
=================================

SKPAR is a parameter-optimisation framework for the 
Density Functional Tight-Binding (DFTB) theory.

.. _Python: http://www.python.org
.. _`DFTB+`: http://www.dftb-plus.info/
.. _Lodestar: http://yangtze.hku.hk/new/software.php
.. _dftb.org: http://www.dftb.org/home/
.. _`MIT license`: https://opensource.org/licenses/MIT


News
====
   
   * SKPAR version 0.2.0 released: September 2017

        - New Configuration section in input file allows for individual
          directory for each model evaluation, i.e. each parameter set.
          Be sure to check the relevant part in :ref:`reference`.
        - Strict bounds for PSO particle space, applied per dimension
        - Minor bug fixes

   * SKPAR version 0.1.0 released: February 2017.

Contents
==================

.. toctree::
   :maxdepth: 2

   about
   install
   commands
   tutorials/tutorials
   reference
   modules
   license
   develop
   contributors


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

